@@ -1,4 +1,4 @@
-/* Copyright (C) 2003-2009 Nadav Har'El and Dan Kenigsberg */
+/* Copyright (C) 2003-2015 Nadav Har'El and Dan Kenigsberg */
 
 /* This header file defines the Hspell Hebrew spellchecking API in C, as
    implemented by the libhspell.a library.
@@ -12,7 +12,7 @@
    API this header file supports. Note that this API might change.
 */
 #define HSPELL_VERSION_MAJOR 1
-#define HSPELL_VERSION_MINOR 1
+#define HSPELL_VERSION_MINOR 3
 #define HSPELL_VERSION_EXTRA ""
 
 
@@ -31,7 +31,7 @@ int hspell_check_word(struct dict_radix *dict,
 		      const char *word, int *preflen);
 void hspell_trycorrect(struct dict_radix *dict,
 		       const char *w, struct corlist *cl);
-int hspell_is_canonic_gimatria(const char *w);
+unsigned int hspell_is_canonic_gimatria(const char *w);
 
 void hspell_uninit(struct dict_radix *dict);
 
@@ -70,7 +70,7 @@ typedef int hspell_word_split_callback_func(const char *word,
 
 /* find all legal splittings of word into a baseword and a prefix. call enumf
  * for every such split. */
-int hspell_enum_splits(struct dict_radix *dict, const char *word, 
+int hspell_enum_splits(struct dict_radix *dict, const char *word,
 	hspell_word_split_callback_func *enumf);
 
 #endif /* INCLUDED_HSPELL_H */
